summaryrefslogtreecommitdiff
path: root/src/wram.asm
diff options
context:
space:
mode:
Diffstat (limited to 'src/wram.asm')
-rw-r--r--src/wram.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/wram.asm b/src/wram.asm
index ef5c90a..1215b3e 100644
--- a/src/wram.asm
+++ b/src/wram.asm
@@ -1218,8 +1218,8 @@ wAIPlayerPrizeCount:: ; cdd2
wAIOpponentPrizeCount:: ; cdd3
ds $1
-; AI stores the energy type to look for here
-wTempEnergyTypeToLook:: ; cdd4
+; AI stores the card ID to look for here
+wTempCardIDToLook:: ; cdd4
ds $1
ds $6